<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/vertebres?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 1
	'1_donnee' => '1 record',

	// N
	'nb_donnees' => '@nb@ records',

	// T
	'titre_tables' => 'Database tables'
);

?>
